@@ -281,7 +281,8 @@ def check_args():
                         required=False, type=str)
     parser.add_argument('-m', '--mergedretrieval', dest='merged', action='store_true',
                         help="merge and retrieve together adjacent entries (requires more memory \
-                        and processing but could prove faster for remote extraction)", required=False)
+                        and processing but could prove much faster for remote extraction)",
+                        required=False)
     parser.add_argument('-v', '--verbose', dest='verbose', action='store_true',
                         help="verbose operation", required=False)
     parser.add_argument('-d', '--duplicates', dest='duplicates', action='store_true',
